@@ -2,7 +2,7 @@ package TestApp::Plugin::Bar;
 
 use strict;
 use warnings;
-use Moose::Role;
+use Mouse::Role;
 
 around bar => sub{ 'override bar' };
 
